Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckUserCredentials ¶
CheckUserCredentials check to see if credentials of a user is correct
func CreateNewUser ¶
CreateNewUser is the service that creates new users - for now only
func GetLatestPosts ¶
GetLatestPosts return a array with the latest posts created
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.